ret_err

Macro ret_err 

macro_rules! ret_err {
    ($r:expr) => { ... };
}
Sometimes, in the try_fn_catch macro, the ? operator breaks and the return type is unknown. This macro is a copy of the old try! macro, but for some reason I do not understand, this does work.